@@ -71,7 +71,15 @@ def sql(key):
         'AgentJobTemplateID': {'sql': "SELECT id FROM AgentJobTemplate", 'database': 'AnyRobot'},
         'JobID': {'sql': "SELECT id FROM AgentJobInfo;", 'database': 'AnyRobot'},
         'uploadID': {'sql': "SELECT id FROM Upload;", 'database': 'AnyRobot'},
-        'uninstallHostID': {'sql':"SELECT id From AgentHost WHERE ip='192.168.84.178';",'database': 'AnyRobot'}
+        'uninstallHostID': {'sql':"SELECT id From AgentHost WHERE ip='10.4.15.54';",'database': 'AnyRobot'},
+        'entitygroupId': {'sql':"SELECT id From KAIEntityGroup ;",'database': 'AnyRobot'},
+        'serviceKpiId': {'sql':"SELECT id From KAIKpi ;",'database': 'AnyRobot'},
+        'serviceHeathId': {'sql':"SELECT serviceId From KAIHealth ;",'database': 'AnyRobot'},
+        'KAIAlertId': {'sql':"SELECT id From KAIAlert ;",'database': 'AnyRobot'},
+        'KAIBusinessId': {'sql':"SELECT id From KAIBusiness ;",'database': 'AnyRobot'},
+        'graphName': {'sql':"SELECT graph_name From graph ;",'database': 'AnyRobot'},
+        'ScheduleTaskId': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'},
+        'ScheduleTaskId1': {'sql':"SELECT id From ScheduleTask ;",'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
