@@ -73,7 +73,8 @@ def filed(key,inquire=[]):
         'InspectionID': zx.search().createInspectionID,
         'InspectionTaskID': zx.search().createInspectionTaskID,
         'ExportFileID': zx.search().createExportFileID,
-        'RepeatInspectionName': zx.search().getRepeatInspectionName
+        'RepeatInspectionName': zx.search().getRepeatInspectionName,
+        'agentDeployIp':ip.date().getAentHostIp
     }
 
     switcher = SERVICE_KPI_
@@ -84,9 +85,9 @@ def filed(key,inquire=[]):
 
 if __name__ == '__main__':
     setting.host = ""
-    setting.database = 'AnyRobot'
+    setting.database = ''
     setting.password = ''
-    setting.port = 30006
+    setting.port = 3306
     setting.user = ''
-    date = filed("UpdateTimeID")
+    date = filed("")
     print(date)
\ No newline at end of file
